@@ -1,9 +1,11 @@
 import re
+import json
 from logging import getLogger, Logger
 from requests import Session, Response
-from typing import Any, List, Type, TypeVar, Tuple
+from typing import Any, cast, List, Type, TypeVar, Tuple, Union
+from typing_extensions import Literal
 
-from . import Config, from_dict, from_list
+from . import Config, from_dict, from_list, Message, Results
 
 
 T = TypeVar("T", bound="BaseDapodik")
@@ -82,7 +84,7 @@ class BaseDapodik:
         params: dict = None,
         page: int = 1,
         start: int = 0,
-        limit: int = 50,
+        limit: Union[int, Literal["unlimited"]] = 50,
         prefix: str = "rest/",
         **kwargs: Any,
     ) -> Response:
@@ -93,7 +95,8 @@ class BaseDapodik:
         }
         if params:
             params_.update(params)
-        return self.session.get(self._url(prefix + url), params=params_, **kwargs)
+        filename = prefix + url if prefix else url
+        return self.session.get(self._url(filename), params=params_, **kwargs)
 
     def _post(
         self,
@@ -111,6 +114,14 @@ class BaseDapodik:
             **kwargs,
         )
 
+    def _put(
+        self, url: str, id: str = "", data: dict = None, prefix: str = "rest/", **kwargs
+    ):
+        url = url + id if url.endswith("/") else url + "/" + id
+        filename = prefix + url if prefix else url
+        headers = {"Referer": self.server, "Content-Type": "application/json"}
+        return self.session.put(self._url(filename), data=json.dumps(data), headers=headers, **kwargs)
+
     def _url(self, url: str) -> str:
         if not url.startswith(self.server):
             return self.server + url.lstrip("/")
@@ -121,3 +132,11 @@ class BaseDapodik:
 
     def _fl(self, t: Type[U], datas: List[dict] = None) -> List[U]:
         return from_list(t, datas) if datas else list()
+
+    def _fr(self, t: Type[U], data: dict) -> List[U]:
+        if "rows" in data:
+            data["rows"] = self._fl(t, data["rows"])
+        return cast(List[U], Results[U](**data))
+
+    def _msg(self, data: dict) -> Message:
+        return Message(**data)  # type: ignore
