@@ -1,13 +1,15 @@
 from requests import Session
 
 from dapodik import __semester__
-from dapodik.base import BaseDapodik, HEADERS, Config
+from dapodik.base import BaseDapodik, HEADERS, Config, Defaults
 from dapodik.utils.decorator import lazy
 
 from . import BaseAuth
 from . import BaseRest
 from . import BaseSekolah
+from . import BaseSarpras
 from . import BasePesertaDidik
+from . import BaseRombonganBelajar
 from . import BaseValidasi
 
 
@@ -21,8 +23,17 @@ class Dapodik(BaseDapodik):
         session: Session = Session(),
         pengguna: int = 0,
         rememberme: bool = True,
+        get_sekolah_id: bool = True,
+        defaults: Defaults = None,
     ):
-        config = Config(username, password, server, semester_id)
+        config = Config(
+            username=username,
+            password=password,
+            server=server,
+            semester_id=semester_id,
+            session=session,
+            defaults=defaults,
+        )
         super(Dapodik, self).__init__(config)
         self.session.headers.update(HEADERS)
         self.daftar_pengguna = self.auth.login(
@@ -30,6 +41,9 @@ class Dapodik(BaseDapodik):
         )
         if self.daftar_pengguna:
             self.logger.info(f"Berhasil login {username}")
+        if get_sekolah_id:
+            sekolah = self.sekolah.sekolah()
+            self.config.sekolah_id = sekolah.sekolah_id
 
     @property  # type: ignore
     @lazy
@@ -46,6 +60,16 @@ class Dapodik(BaseDapodik):
     def rest(self) -> BaseRest:
         return BaseRest(self.config)
 
+    @property  # type: ignore
+    @lazy
+    def rombongan_belajar(self) -> BaseRombonganBelajar:
+        return BaseRombonganBelajar(self.config)
+
+    @property  # type: ignore
+    @lazy
+    def sarpras(self) -> BaseSarpras:
+        return BaseSarpras(self.config)
+
     @property  # type: ignore
     @lazy
     def sekolah(self) -> BaseSekolah:
