@@ -11,7 +11,7 @@ class PesertaDidik:
     jenis_kelamin: str = freeze()
     nisn: str = freeze(default="")
     nik: str = freeze(default="")
-    no_kk: str
+    no_kk: str = ""
     tempat_lahir: str = freeze()
     tanggal_lahir: date = freeze()
     agama_id: int
@@ -22,32 +22,32 @@ class PesertaDidik:
     nama_dusun: str
     desa_kelurahan: str
     kode_wilayah: str
-    kode_pos: int
+    kode_pos: Optional[int] = None
     lintang: str = "0"
     bujur: str = "0"
-    jenis_tinggal_id: int
-    alat_transportasi_id: int
+    jenis_tinggal_id: int = 1
+    alat_transportasi_id: int = 1
     nik_ayah: str
     nik_ibu: str
     anak_keberapa: int = 1
     nik_wali: Optional[str]
     nomor_telepon_rumah: Optional[str]
     nomor_telepon_seluler: Optional[str]
-    email: Optional[str]
-    penerima_kps: int
-    no_kps: Optional[str]
-    layak_pip: int
-    penerima_kip: int
-    no_kip: Optional[str]
-    nm_kip: int
-    no_kks: Optional[str]
-    reg_akta_lahir: str
-    id_layak_pip: Optional[int]
-    id_bank: Optional[int] = freeze()
-    rekening_bank: Optional[str] = freeze()
-    nama_kcp: Optional[str] = freeze()
-    rekening_atas_nama: Optional[str] = freeze()
-    status_data: int = freeze()
+    email: Optional[str] = ""
+    penerima_kps: int = 0
+    no_kps: Optional[str] = None
+    layak_pip: int = 0
+    penerima_kip: int = 0
+    no_kip: Optional[str] = None
+    nm_kip: Optional[str] = None
+    no_kks: Optional[str] = None
+    reg_akta_lahir: str = ""
+    id_layak_pip: Optional[int] = None
+    id_bank: Optional[int] = freeze(default=None)
+    rekening_bank: Optional[str] = freeze(default=None)
+    nama_kcp: Optional[str] = freeze(default=None)
+    rekening_atas_nama: Optional[str] = freeze(default=None)
+    status_data: Optional[int] = freeze(default=None)
     nama_ayah: str
     tahun_lahir_ayah: int
     jenjang_pendidikan_ayah: int
@@ -66,20 +66,15 @@ class PesertaDidik:
     pekerjaan_id_wali: int
     penghasilan_id_wali: int
     kewarganegaraan: str = field(default="ID")
-    create_date: datetime = freeze()
-    last_update: datetime = freeze()
-    soft_delete: int = freeze()
-    last_sync: datetime = freeze()
-    updater_id: UUID = freeze()
     registrasi_id: UUID = freeze()
-    jurusan_sp_id: None
+    jurusan_sp_id: Optional[str] = freeze()
     sekolah_id: UUID = freeze()
     jenis_pendaftaran_id: int
     nipd: int
     tanggal_masuk_sekolah: date
     jenis_keluar_id: Optional[int]
     tanggal_keluar: Optional[datetime]
-    keterangan: str
+    keterangan: str = freeze()
     no_skhun: Optional[str]
     no_peserta_ujian: Optional[str]
     no_seri_ijazah: Optional[str]
@@ -93,11 +88,20 @@ class PesertaDidik:
     ket_keluar: Optional[str]
     anggota_rombel_id: Optional[UUID]
     tingkat_pendidikan_id: Optional[int]
-    rombel_saat_ini: None
-    rombel: None
-    id_bank_str: None
+    rombel_saat_ini: str = freeze(default=None)
+    rombel: str = freeze(default=None)
+    id_bank_str: Optional[str] = freeze(default=None)
     kewarganegaraan_str: str = ""
     nomor_induk_pd: int
-    yatim_piatu: bool
-    konfirmasi_mutasi: int
-    vld_count: int = 0
+    yatim_piatu: bool = False
+    konfirmasi_mutasi: int = freeze(default=0)
+    vld_count: Optional[int] = freeze(default=0)
+    # Metadata
+    create_date: Optional[datetime] = freeze(default=None)
+    last_update: Optional[datetime] = freeze(default=None)
+    soft_delete: Optional[int] = freeze(default=None)
+    last_sync: Optional[datetime] = freeze(default=None)
+    updater_id: Optional[UUID] = freeze(default=None)
+
+    def __str__(self):
+        return self.nama
