@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class Biblio:
     id_biblio: str
     id_freq: Optional[str]
@@ -38,3 +38,6 @@ class Biblio:
     id_gmd_str: str
     tingkat_pendidikan_id: str
     tingkat_pendidikan_id_str: str
+
+    def __str__(self):
+        return self.title
