@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class JenisRombel:
     jenis_rombel: str
     nm_jenis_rombel: str
@@ -12,3 +12,6 @@ class JenisRombel:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.nm_jenis_rombel
