@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class KebutuhanKhusus:
     kebutuhan_khusus_id: int
     kebutuhan_khusus: str
@@ -31,3 +31,6 @@ class KebutuhanKhusus:
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
+
+    def __str__(self):
+        return self.kebutuhan_khusus
