@@ -4,7 +4,7 @@ from typing import Optional
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class Kurikulum:
     kurikulum_id: int
     nama_kurikulum: str
@@ -18,3 +18,6 @@ class Kurikulum:
     expired_date: Optional[datetime]
     last_sync: datetime
     sek: str
+
+    def __str__(self):
+        return self.nama_kurikulum
