@@ -3,7 +3,7 @@ from datetime import datetime
 from dapodik.base import dataclass
 
 
-@dataclass(frozen=True)
+@dataclass(frozen=True, slots=True)
 class SyncLog:
     id_instalasi: str
     begin_sync: datetime
