@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Sekolah, Ptk, JenisSarana
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass, freeze
 
 
-@set_meta("id_angkutan", sekolah=Sekolah, ptk=Ptk, jenis_sarana=JenisSarana)
-@attr.dataclass
-class Angkutan(DapodikObject):
+@dataclass
+class Angkutan:
     id_angkutan: str
     sekolah_id: str
     ptk_id: Optional[str]
@@ -30,16 +28,14 @@ class Angkutan(DapodikObject):
     no_bpkb: Optional[str]
     alamat: Optional[str]
     asal_data: Optional[str]
-    create_date: datetime
-    last_update: datetime
-    soft_delete: str
-    last_sync: datetime
-    updater_id: Optional[str]
     jenis_sarana_id_str: str
     sekolah_id_str: str
     vld_count: int
+    create_date: datetime = freeze(default=None)
+    last_update: datetime = freeze(default=None)
+    soft_delete: str = freeze(default=None)
+    last_sync: datetime = freeze(default=None)
+    updater_id: Optional[str] = freeze(default=None)
 
-    @property
-    def kepemilikan_sarpras(self):
-        # TODO API
-        return self.kepemilikan_sarpras_id
+    def __str__(self):
+        return self.nama
