@@ -1,15 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Sekolah, JenisPrasarana, Bangunan
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass, freeze
 
 
-@set_meta(
-    "id_ruang", jenis_prasarana=JenisPrasarana, sekolah=Sekolah, bangunan=Bangunan
-)
-@attr.dataclass
-class Ruang(DapodikObject):
+@dataclass
+class Ruang:
     id_ruang: str
     jenis_prasarana_id: int
     sekolah_id: str
@@ -38,11 +34,11 @@ class Ruang(DapodikObject):
     luas_finish_plafon_m2: Optional[str]
     luas_finish_dinding_m2: Optional[str]
     luas_finish_kpj_m2: Optional[str]
-    create_date: datetime
-    last_update: datetime
-    soft_delete: str
-    last_sync: datetime
-    updater_id: str
     jenis_prasarana_id_str: str
     id_bangunan_str: str
     sekolah_id_str: str
+    create_date: datetime = freeze(default=None)
+    last_update: datetime = freeze(default=None)
+    soft_delete: str = freeze(default=None)
+    last_sync: datetime = freeze(default=None)
+    updater_id: str = freeze(default=None)
